@@ -12,9 +12,7 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  * The Sushi project hereby grant permission for non-gpl compatible GStreamer
  * plugins to be used and distributed together with GStreamer and Sushi. This
@@ -25,8 +23,6 @@
  *
  */
 
-#include <config.h>
-
 #include "sushi-file-loader.h"
 
 #include <gtk/gtk.h>
@@ -585,14 +581,13 @@ sushi_file_loader_get_icon (SushiFileLoader *self)
 
   info = gtk_icon_theme_lookup_by_gicon (gtk_icon_theme_get_default (),
                                          g_file_info_get_icon (self->priv->info),
-                                         256,
-                                         GTK_ICON_LOOKUP_GENERIC_FALLBACK);
+                                         256, 0);
 
   if (info == NULL)
     return NULL;
 
   retval = gtk_icon_info_load_icon (info, &error);
-  gtk_icon_info_free (info);
+  g_object_unref (info);
 
   if (error != NULL) {
     gchar *uri;
